diff Platforms/Wasm/Defaults.cpp @ 386:e33659decec5

renamed UpdateContent() as DoAnimation()
author Sebastien Jodogne <s.jodogne@gmail.com>
date Fri, 09 Nov 2018 17:06:28 +0100
parents 6cc3ce74dc05
children 3e6e10a5a6c8
line wrap: on
line diff
--- a/Platforms/Wasm/Defaults.cpp	Wed Nov 07 20:49:41 2018 +0100
+++ b/Platforms/Wasm/Defaults.cpp	Fri Nov 09 17:06:28 2018 +0100
@@ -102,13 +102,13 @@
     printf("StartWasmApplication - completed\n");
   }
   
-  void EMSCRIPTEN_KEEPALIVE NotifyUpdateContent()
+  void EMSCRIPTEN_KEEPALIVE WasmDoAnimation()
   {
     for (auto viewport : viewports_) {
-      // TODO Only launch the JavaScript timer if "HasUpdateContent()"
-      if (viewport->HasUpdateContent())
+      // TODO Only launch the JavaScript timer if "HasAnimation()"
+      if (viewport->HasAnimation())
       {
-        viewport->UpdateContent();
+        viewport->DoAnimation();
       }
 
     }